{namespace neos=TYPO3\Neos\ViewHelpers}
<link rel="shortcut icon" href="/favicon.ico">

<meta name="viewport" content="width=device-width, initial-scale=1">
<meta http-equiv="X-UA-Compatible" content="IE=edge">
<script src="{f:uri.resource(path: 'js/modernizr-2.6.2-respond-1.1.0.min.js', package: 'MOC.Pivot')}"></script>
